@@ -1,9 +1,9 @@
-package RevML::Doctype::v0_26 ;
+package RevML::Doctype::v0_28 ;
 
 ##
 ## THIS FILE CREATED AUTOMATICALLY: YOU MAY LOSE ANY EDITS IF YOU MOFIFY IT.
 ##
-## When: Fri Aug 18 22:39:26 2000
+## When: Fri Dec 15 07:57:43 2000
 ## By:   RevML::Doctype, v0.1, (XML::Doctype, v0.11)
 ##
 
@@ -34,7 +34,7 @@ $doctype = bless( [
         'PATHS' => 6
       },
       undef,
-      '^<name><type>(?:<cvs_info>|<p4_info>|<source_safe_info>|<pvcs_info>)?(?:<branch_id>)?<rev_id>(?:<change_id>)?<time>(?:<mod_time>)?<user_id>(?:<p4_action>|<sourcesafe_action>)?(?:<label>)*(?:<lock>)?(?:<comment>)?(?:<delete>|<move>|(?:<content>|(?:<base_name>)?<base_rev_id><delta>)<digest>)$',
+      '^<name><type>(?:<rev_id>(?:<change_id>)?<digest>|(?:<cvs_info>|<p4_info>|<source_safe_info>|<pvcs_info>)?(?:<branch_id>)?<rev_id>(?:<change_id>)?<time>(?:<mod_time>)?<user_id>(?:<p4_action>|<sourcesafe_action>)?(?:<label>)*(?:<lock>)?(?:<comment>)?(?:<delete>|<move>|(?:<content>|(?:<base_name>)?<base_rev_id><delta>)<digest>))$',
       1,
       'rev',
       [
@@ -67,10 +67,12 @@ $doctype = bless( [
     'cvs_info' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'cvs_info',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'branch_map_sn' => bless( [
       {},
@@ -83,26 +85,32 @@ $doctype = bless( [
     'base_name' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'base_name',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'user_id' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'user_id',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'rep_desc' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'rep_desc',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'p4_action' => bless( [
       {},
@@ -115,10 +123,12 @@ $doctype = bless( [
     'rev_root' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'rev_root',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'time' => bless( [
       {},
@@ -131,10 +141,12 @@ $doctype = bless( [
     'comment' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'comment',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'branch_id' => bless( [
       {},
@@ -194,10 +206,12 @@ $doctype = bless( [
     'p4_info' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'p4_info',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'sourcesafe_action' => bless( [
       {},
@@ -215,6 +229,23 @@ $doctype = bless( [
       'rev_id',
       []
     ], 'XML::Doctype::ElementDecl' ),
+    'char' => bless( [
+      {},
+      {
+        'code' => bless( [
+          {},
+          undef,
+          'code',
+          undef,
+          '#REQUIRED',
+          'CDATA'
+        ], 'XML::Doctype::AttDef' )
+      },
+      'EMPTY',
+      1,
+      'char',
+      []
+    ], 'XML::Doctype::ElementDecl' ),
     'file_count' => bless( [
       {},
       undef,
@@ -243,25 +274,29 @@ $doctype = bless( [
           '(none|base64)'
         ], 'XML::Doctype::AttDef' )
       },
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'delta',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'source_safe_info' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'source_safe_info',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'revml' => bless( [
       {},
       {
         'version' => bless( [
           {},
-          '0.26',
+          '0.28',
           'version',
           undef,
           '#FIXED',
@@ -287,10 +322,12 @@ $doctype = bless( [
     'name' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'name',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'mod_time' => bless( [
       {},
@@ -311,11 +348,12 @@ $doctype = bless( [
     'pvcs_info' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?|<trunk_rev_id>|<attrib>)*$',
+      '^(?:(?:#PCDATA)?|<trunk_rev_id>|<attrib>|<char>)*$',
       1,
       'pvcs_info',
       [
         'attrib',
+        'char',
         'trunk_rev_id'
       ]
     ], 'XML::Doctype::ElementDecl' ),
@@ -338,10 +376,12 @@ $doctype = bless( [
     'label' => bless( [
       {},
       undef,
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'label',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'type' => bless( [
       {},
@@ -408,10 +448,12 @@ $doctype = bless( [
           '(none|base64)'
         ], 'XML::Doctype::AttDef' )
       },
-      '^(?:(?:#PCDATA)?)$',
+      '^(?:(?:#PCDATA)?|<char>)*$',
       1,
       'content',
-      []
+      [
+        'char'
+      ]
     ], 'XML::Doctype::ElementDecl' ),
     'lock' => bless( [
       {},
@@ -464,6 +506,8 @@ $doctype->[1]{'cvs_branch_id'}[0] = $doctype->[1]{'rev'}[0];
 $doctype->[1]{'p4_info'}[0] = $doctype->[1]{'rev'}[0];
 $doctype->[1]{'sourcesafe_action'}[0] = $doctype->[1]{'rev'}[0];
 $doctype->[1]{'rev_id'}[0] = $doctype->[1]{'rev'}[0];
+$doctype->[1]{'char'}[0] = $doctype->[1]{'rev'}[0];
+$doctype->[1]{'char'}[1]{'code'}[0] = $doctype->[1]{'digest'}[1]{'type'}[0];
 $doctype->[1]{'file_count'}[0] = $doctype->[1]{'rev'}[0];
 $doctype->[1]{'delta'}[0] = $doctype->[1]{'rev'}[0];
 $doctype->[1]{'delta'}[1]{'type'}[0] = $doctype->[1]{'digest'}[1]{'type'}[0];
